package com.example.libreria;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RatingBar;
import android.widget.Toast;

import com.example.libreria.Util.ISBN;
import com.example.libreria.controller.BookController;
import com.example.libreria.entities.Book;

public class BookEdit extends ActionBarActivity {

	private Button btnSave, btnISBN, btnScan;
	private EditText txtTitulo, txtISBN, txtAutor, txtNumPages;
	private int id;
	private char modo;
	private Book book;
	RatingBar valoracion;
	private SharedPreferences pref;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.book_edit);

		pref = this.getSharedPreferences("com.example.libreria_preferences",
				Context.MODE_PRIVATE);

		txtTitulo = (EditText) findViewById(R.id.title);
		txtISBN = (EditText) findViewById(R.id.ISBN);
		txtAutor = (EditText) findViewById(R.id.autor);
		txtNumPages = (EditText) findViewById(R.id.numPages);
		valoracion = (RatingBar) findViewById(R.id.valoracion);

		btnScan = (Button) findViewById(R.id.btnScan);
		btnSave = (Button) findViewById(R.id.btnSave);
		btnISBN = (Button) findViewById(R.id.btnFindISBN);

		if (!pref.getBoolean("checkServer", true)) { // webService ISBN
			btnISBN.setVisibility(View.GONE);
		} else {
			btnISBN.setVisibility(View.VISIBLE);
		}

		btnScan.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				ScanEAN();
			}
		});

		btnISBN.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				callISBN();
			}
		});

		btnSave.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				guardarDatos();
			}
		});

		modo = 'N'; // New

		if (getIntent().getExtras() != null) {
			modo = 'M'; // Modify
			Bundle extras = getIntent().getExtras();
			id = extras.getInt("id");
			book = BookController.elemento(id);
			cargarDatos(id);
		}

	}

	private void ScanEAN() {
		Intent intent = new Intent("com.google.zxing.client.android.SCAN");
		intent.putExtra("SCAN_MODE", "PRODUCT_MODE");
		this.startActivityForResult(intent, 1);
	}

	private void callISBN() {
		if (txtISBN.getText().length() == 0) {
			AlertDialog alertDialog = new AlertDialog.Builder(this).create();
			alertDialog.setTitle(getResources().getString(R.string.buscarISBN));
			alertDialog.setMessage(getResources().getString(R.string.rellenarISBN));
			alertDialog.setButton(getResources().getString(R.string.aceptar),
					new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int which) {
							// aqu puedes aadir funciones
						}
					});
			alertDialog.setIcon(R.drawable.ic_launcher);
			alertDialog.show();
		} else {
			if (pref.getBoolean("checkServer", true)) { // Sensores
				ISBNTask tarea = new ISBNTask();
				tarea.execute(0);
			}
		}

	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		if (resultCode == RESULT_OK) {
			txtISBN.setText(data.getStringExtra("SCAN_RESULT"));
			// En asyncTask
			// ISBN.callISBNService();
			if (pref.getBoolean("checkServer", true)) { // Sensores
				ISBNTask tarea = new ISBNTask();
				tarea.execute(0);
			}
		}
	}

	private void cargarDatos(int pos) {
		txtTitulo.setText(book.getTitulo());
		txtISBN.setText(book.getIsbn());
		txtAutor.setText(book.getAutor());
		// txtNumPages.setText(book.getPaginas());
		txtNumPages.setText(String.valueOf(book.getPaginas()));
		valoracion.setRating(book.getValoracion());
	}

	private void guardarDatos() {

		int newid;
		
		if (txtTitulo.getText().length() > 0) {
			Book book = new Book();
			// book.setId(this.book.getId());
			book.setTitulo(txtTitulo.getText().toString());
			book.setIsbn(txtISBN.getText().toString());
			book.setAutor(txtAutor.getText().toString());
			book.setEstado("A");
			if (txtNumPages.getText().toString().length() > 0)
				book.setPaginas(Integer.parseInt(txtNumPages.getText()
						.toString()));
			book.setValoracion(valoracion.getRating());

			if (modo == 'N') { // Nuevo
				newid = BookController.insert(book);
			}

			else if (modo == 'M') { // Update
				book.setId(this.book.getId());
				BookController.update(book);
			}

			Toast toast1 = Toast.makeText(getApplicationContext(),
					getResources().getString(R.string.guardado),
					Toast.LENGTH_SHORT);
			toast1.show();
			
			finish();
			
		} else {
			Toast toast1 = Toast.makeText(getApplicationContext(),
					getResources().getString(R.string.tituloObligatorio),
					Toast.LENGTH_SHORT);
			toast1.show();
		}		

	}

	class ISBNTask extends AsyncTask<Integer, Integer, Integer> {
		private ProgressDialog progreso;

		@Override
		protected void onPreExecute() {
			progreso = new ProgressDialog(BookEdit.this);
			progreso.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
			progreso.setMessage(getResources().getString(R.string.obteniendo)
					+ "...");
			progreso.setCancelable(true);
			progreso.setOnCancelListener(new OnCancelListener() {
				@Override
				public void onCancel(DialogInterface dialog) {
					ISBNTask.this.cancel(true);
				}
			});
			progreso.setMax(100);
			progreso.setProgress(0);
			progreso.show();
		}

		@Override
		protected Integer doInBackground(Integer... n) {
			int res = 1;
			ISBN.callISBNService(txtISBN.getText().toString());
			// publishProgress(i * 100 / n[0]);

			return res;
		}

		@Override
		protected void onProgressUpdate(Integer... porc) {
			progreso.setProgress(porc[0]);
		}

		@Override
		protected void onPostExecute(Integer res) {
			try {
				if ((this.progreso != null) && this.progreso.isShowing()) {
					this.progreso.dismiss();
				}
			} catch (final IllegalArgumentException e) {
				// Handle or log or ignore
			} catch (final Exception e) {
				// Handle or log or ignore
			} finally {
				this.progreso = null;
			}

			if (ISBN.getError().length() > 0) {
				AlertDialog alertDialog = new AlertDialog.Builder(BookEdit.this)
						.create();
				alertDialog.setTitle(getResources().getString(R.string.buscarISBN));
				alertDialog.setMessage(getResources().getString(R.string.noISBN));
				alertDialog.setButton(getResources().getString(R.string.aceptar),
						new DialogInterface.OnClickListener() {
							public void onClick(DialogInterface dialog,
									int which) {
								// aqu puedes aadir funciones
							}
						});
				alertDialog.setIcon(R.drawable.ic_launcher);
				alertDialog.show();
			}
			txtTitulo.setText(ISBN.getBook().getTitulo());
			txtAutor.setText(ISBN.getBook().getAutor());
			txtNumPages.setText(String.valueOf(ISBN.getBook().getPaginas()));
		}

		@Override
		protected void onCancelled() {
			// salida.append("cancelado\n");
		}
	}

}
