package com.example.libreria;

import java.util.Date;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;

import com.example.libreria.controller.BookController;
import com.example.libreria.controller.ContactController;
import com.example.libreria.controller.LoanController;
import com.example.libreria.entities.Book;
import com.example.libreria.entities.Contact;
import com.example.libreria.entities.Loan;

import android.provider.ContactsContract.Data;
import android.provider.ContactsContract.CommonDataKinds.Phone;

public class BookView extends Activity {

	private Button btnModificar, btnPrestar, btnEliminar, btnContact;
	private TextView txtTitulo, txtISBN, txtAutor, txtNumPages;
	private RatingBar rating;
	private int id;
	private Contact c;

	private Book book;

	private static final int REQUEST_CHOOSE_PHONE = 1;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.book_view);

		btnModificar = (Button) findViewById(R.id.btnModify);
		btnPrestar = (Button) findViewById(R.id.btnLoan);
		btnEliminar = (Button) findViewById(R.id.btnDelete);
		btnContact = (Button) findViewById(R.id.btnContact);
		rating = (RatingBar) findViewById(R.id.valoracion);

		txtTitulo = (TextView) findViewById(R.id.title);
		txtISBN = (TextView) findViewById(R.id.ISBN);
		txtAutor = (TextView) findViewById(R.id.autor);
		txtNumPages = (TextView) findViewById(R.id.numPages);

		btnModificar.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				modificar();
			}
		});

		btnPrestar.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				prestar();
			}
		});

		btnEliminar.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				eliminar();
			}
		});
		
		

		if (getIntent().getExtras() != null) {
			Bundle extras = getIntent().getExtras();
			id = extras.getInt("id");
			book = BookController.elemento(id);
			cargarDatos(id);			
		}

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.menu_book_view, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		Intent intent;
		switch (item.getItemId()) {
		case R.id.accion_compartir:
			intent = new Intent(Intent.ACTION_SEND);
			intent.setType("text/plain");
			intent.putExtra(Intent.EXTRA_TEXT,
					book.getTitulo() + ". " + book.getAutor());
			startActivity(intent);
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}

	private void cargarDatos(int pos) {
		txtTitulo.setText(book.getTitulo());
		txtISBN.setText(book.getIsbn());
		txtAutor.setText(book.getAutor());
		rating.setRating(book.getValoracion());
		txtNumPages.setText(String.valueOf(book.getPaginas()));

		if (book.getEstado().equals("L")) {
			btnPrestar.setTag("D");
			btnPrestar.setText(getResources().getString(R.string.devolver));

			Loan l = LoanController.elementoByBook(book.getId());
			//TODO
			c = ContactController.getContact(l.getContactid());
			//c = ContactController.getContactByLookUp(l.getContactlookup());
			
			btnContact.setOnClickListener(new OnClickListener() {
				@Override
				public void onClick(View v) {
					//abrirContacto(c.getId());
					abrirContacto(c.getLookup());
					//abrirContactoNombre(c.getName());
				}
			});

			btnContact.setVisibility(android.view.View.VISIBLE);
			btnContact.setText("Contactar con " + c.getName());
		} else {
			btnContact.setVisibility(android.view.View.GONE);
		}

	}

	private void modificar() {
		Intent intent = new Intent(this, BookEdit.class);
		intent.putExtra("id", id);
		startActivity(intent);
	}

	private void prestar() {
		switch (book.getEstado()) {
		case "A": // Available
			Intent intent = new Intent(this, ChoosePhoneActivity.class);
			startActivityForResult(intent, REQUEST_CHOOSE_PHONE);
			
			break;
		case "L": // loan
			LoanController.borrar(LoanController.elementoByBook(
					this.book.getId()).getId());
			cambiarEstado("A");
			break;
		}

	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if ((requestCode == REQUEST_CHOOSE_PHONE)
				&& (resultCode == Activity.RESULT_OK)) {
			try {
				String phone = data.getStringExtra("phone");
				int contactId = data.getIntExtra("contactId", -1);
				//int contactlookup = data.getIntExtra("lookup", -1);
				LoanController.anyade(new Loan(this.book, new Date(),
						//contactId, "Nombre",contactlookup));
						contactId, "Nombre",0));
				cambiarEstado("L");
				btnContact.setVisibility(android.view.View.VISIBLE);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	private void eliminar() {
		  //Mostrar un mensaje de confirmacin antes de eliminar  
		  AlertDialog.Builder alertDialog = new AlertDialog.Builder(BookView.this); 
		  alertDialog.setMessage(getResources().getString(R.string.deseaEliminar)); 
		  alertDialog.setTitle("Eliminar libro"); 
		  alertDialog.setIcon(android.R.drawable.ic_dialog_alert); 
		  alertDialog.setCancelable(false); 
		  alertDialog.setPositiveButton(getResources().getString(R.string.yes), new DialogInterface.OnClickListener() 
		  { 
		     public void onClick(DialogInterface dialog, int which) 
		    { 
		        //cdigo Java si se ha pulsado s 
		    	 confimadoEliminar();
		     } 
		   }); 
		   alertDialog.setNegativeButton(getResources().getString(R.string.no), new DialogInterface.OnClickListener() 
		   { 
		      public void onClick(DialogInterface dialog, int which) 
		     { 
		        //cdigo java si se ha pulsado no 
		      } 
		    }); 
		    alertDialog.show();
		
		
	}
	
	private void confimadoEliminar() {
		if (book.getEstado().equals("L")) {
			Loan l = LoanController.elementoByBook(this.book.getId());
			if (l != null) {
				LoanController.borrar(l.getId());
			}
		}
		BookController.borrar(id);

		Toast toast1 = Toast.makeText(getApplicationContext(), getResources().getString(R.string.eliminado),
				Toast.LENGTH_SHORT);
		toast1.show();
		this.finish();
	}

	@Override
	protected void onResume() {
		super.onResume();
		if (id != 0) {
			book = BookController.elemento(id);
			cargarDatos(id);
		}
	}

	private void cambiarEstado(String estado) {
		Toast toast;
		switch (estado) {

		case "A": // Available
			book.setEstado("A");
			btnPrestar.setTag("A");
			btnPrestar.setText(getResources().getString(R.string.prestar));
			btnContact.setVisibility(android.view.View.GONE);
			toast = Toast.makeText(getApplicationContext(), getResources().getString(R.string.devuelto),
					Toast.LENGTH_SHORT);
			toast.show();
			break;
		case "L": // loan
			book.setEstado("L");
			btnPrestar.setTag("L");
			btnPrestar.setText(getResources().getString(R.string.devolver));
			toast = Toast.makeText(getApplicationContext(), getResources().getString(R.string.prestado),
					Toast.LENGTH_SHORT);
			toast.show();
			break;
		}
	}

	private void abrirContacto(int id) {
		Uri uri;

		Intent intent = new Intent(Intent.ACTION_VIEW);
		uri = Uri.withAppendedPath(ContactsContract.Contacts.CONTENT_URI, String.valueOf(id));

		Log.i("--LIBRERIA--", uri.toString());
		intent.setData(uri);
		startActivity(intent);
	}
	
	private void abrirContacto(String id) {
		Uri uri;
			
		Intent intent = new Intent(Intent.ACTION_VIEW);

		uri = Uri.withAppendedPath(ContactsContract.Contacts.CONTENT_LOOKUP_URI, id);
		Log.i("--LIBRERIA--", uri.toString());
		intent.setData(uri);
		startActivity(intent);

	}
	
	private void abrirContactoNombre(String name) {
		Uri uri;
		int contactId;
		
		Cursor cur = getContentResolver().query(
				Data.CONTENT_URI,
				new String[] {  Data.CONTACT_ID,Data._ID, Data.DISPLAY_NAME, Phone.NUMBER,
						Phone.TYPE },
				Data.MIMETYPE + "='" + Phone.CONTENT_ITEM_TYPE + "' AND "
						+ Phone.NUMBER + " IS NOT NULL", null,
				Data.DISPLAY_NAME + " ASC");
		
		if (!cur.moveToFirst()) {
		    // Then the cursor isn't empty. Get the contact's id.
		    contactId = cur.getInt(cur.getColumnIndex(Data.CONTACT_ID));
		    abrirContacto(contactId);
		}
		
	}

}
